@@ -2,11 +2,11 @@
 """Data parsing for Biocyc
 
 This module handles the retrieval of data from BioCyc into a local directory.
-The possible type of data that can be download:
+The possible type of data that can be downloaded:
 
 - Metabolites: Normally have an abbreviation or short name.
 - Reactions: Can have the words "RXN" in the identifier. Enzymes can sometimes
-be used instead. The gene information for the reactions is include if found.
+be used instead. The gene information for the reactions is included if found.
 - Pathways
 
 Contact maintainers if other types should be added.
@@ -16,6 +16,7 @@ Important class of the module:
 :class:`cobramod.parsing.base.BaseParser`.
 """
 from contextlib import suppress
+from functools import lru_cache
 from xml.etree.ElementTree import (
     fromstring,
     Element,
@@ -38,38 +39,6 @@ from cobramod.error import (
 from cobramod.parsing.base import BaseParser
 
 
-# Sub databases from Biocyc
-with open(
-    file=str(
-        Path(__file__)
-        .resolve()
-        .parent.parent.joinpath("data")
-        .joinpath("biocyc_db.xml")
-    )
-) as f:
-    databases = parse(source=f)
-# Check actual biocyc database version
-try:
-    response = get(url="https://websvc.biocyc.org/kb-version?orgid=META")
-    response.raise_for_status()
-    kb_version = response.json()["kb-version"]
-    cobramod_kb = databases.find(  # type: ignore
-        "metadata/*[@orgid='META']"
-    ).attrib["version"]
-    # Check that the database version is the one
-    assert kb_version == cobramod_kb
-except HTTPError:
-    warn(
-        message="Could not get the actual Biocyc version", category=UserWarning
-    )
-except AssertionError:
-    warn(
-        message="Biocyc version is not the same in CobraMod. Please inform "
-        + "maintainers.",
-        category=UserWarning,
-    )
-
-
 def _build_reference(root: Any) -> dict:
     """
     Returns a dictionary with the corresponding cross-references and their
@@ -388,7 +357,7 @@ class BiocycParser(BaseParser):
         Returns:
             dict: relevant data for given identifier
         """
-        BiocycParser._check_database(database=database)
+        BiocycParser._check_database(directory=directory, database=database)
         root = retrieve_data(
             directory=directory, identifier=identifier, database=database
         )
@@ -399,16 +368,41 @@ class BiocycParser(BaseParser):
         return BiocycParser._parse(root=root, directory=directory)
 
     @staticmethod
-    def _check_database(database: str):
+    @lru_cache(maxsize=1)
+    def _query_available_dbs() -> Element:
+        """
+        Function to query and cache all existing databases in BioCyc.
+        """
+
+        url = "https://biocyc.org/xmlquery?dbs"
+        response = get(url)
+        response.raise_for_status()
+
+        return fromstring(response.content)
+
+    @staticmethod
+    def _check_database(directory: Path, database: str) -> None:
         """
         Returns the name of the database. This method is used to compare with
         given database name. It will raise a warning if both names are not
         equal or belong to the list of proper names.
         """
-        if not databases.find(f"metadata/*[@orgid='{database}']"):
-            raise WrongParserError(
-                f'Database "{database}" was not found in Biocyc'
-            )
+
+        if not isinstance(database, str) or ":" in database:
+            raise WrongParserError
+
+        databases = BiocycParser._query_available_dbs()
+
+        local_databases = BaseParser._get_local_databases(directory)
+        if local_databases.str.contains(database).any():
+            return
+
+        if databases.find(f"metadata/*[@orgid='{database}']"):
+            return
+
+        raise WrongParserError(
+            f'Database "{database}" was not found in Biocyc'
+        )
 
     @staticmethod
     def _read_file(filename: Path) -> Element:
@@ -497,7 +491,6 @@ def retrieve_data(directory: Path, identifier: str, database: str) -> Element:
     """
     if directory.exists():
         data_dir = directory.joinpath(database)
-        data_dir.mkdir(exist_ok=True)
         filename = data_dir.joinpath(f"{identifier}.xml")
         debug_log.debug(f'Searching "{identifier}" in directory "{database}".')
         # Search for the file on directory. Otherwise retrive from database
@@ -517,7 +510,16 @@ def retrieve_data(directory: Path, identifier: str, database: str) -> Element:
                 response.raise_for_status()
                 # defining root
                 root = fromstring(response.text)
+
+                metadata = root.find("metadata/PGDB")
+                assert metadata is not None
+                orgid = str(metadata.get("orgid"))
+                version = str(metadata.get("version"))
+
+                BaseParser.check_database_version(directory, orgid, version)
+
                 tree = ElementTree(root)
+                data_dir.mkdir(exist_ok=True)
                 tree.write(str(filename))
                 debug_log.info(
                     f'Object "{identifier}" found in database. Saving in '
@@ -533,6 +535,7 @@ def retrieve_data(directory: Path, identifier: str, database: str) -> Element:
                         identifier=identifier,
                         database=database,
                     )
+
                 return root
             except HTTPError:
                 msg = f'"{identifier}" is not available in "{database}"'
