@@ -2,11 +2,11 @@
 """Data parsing for PlantCyc
 
 This module handles the retrieval of data from PlantCyc into a local directory.
-The possible type of data that can be download:
+The possible type of data that can be downloaded:
 
 - Metabolites: Normally have an abbreviation or short name.
 - Reactions: Can have the words "RXN" in the identifier. Enzymes can sometimes
-be used instead. The gene information for the reactions is include if found.
+be used instead. The gene information for the reactions is included if found.
 - Pathways
 
 Contact maintainers if other types should be added.
@@ -16,6 +16,7 @@ Important class of the module:
 :class:`cobramod.parsing.base.BaseParser`.
 """
 from contextlib import suppress
+from functools import lru_cache
 from xml.etree.ElementTree import (
     fromstring,
     Element,
@@ -371,14 +372,44 @@ class PlantCycParser(BaseParser):
         return PlantCycParser._parse(root=root, directory=directory)
 
     @staticmethod
-    def _check_database(database: str):
+    @lru_cache(maxsize=1)
+    def _query_available_dbs() -> Element:
         """
-        Returns name of the database. It will raise a Error if name is
-        incorrect.
+        Function to query and cache all existing databases in PlantCyc.
         """
+        url = "https://pmn.plantcyc.org/xmlquery?dbs"
+        response = get(url)
+        response.raise_for_status()
+
+        return fromstring(response.content)
+
+    @staticmethod
+    def _check_database(directory: Path, database: str) -> None:
+        """
+        Returns the name of the database. This method is used to compare with
+        given database name. It will raise a warning if both names are not
+        equal or belong to the list of proper names.
+        """
+
         if not isinstance(database, str) or not database.startswith("pmn:"):
             raise WrongParserError
 
+        databases = PlantCycParser._query_available_dbs()
+
+        local_databases = BaseParser._get_local_databases(directory)
+        if local_databases.str.contains(database).any():
+            return
+
+        # obtaining the database name without the prefix "pmn:"
+        database = database.partition("pmn:")[2]
+
+        if databases.find(f"metadata/*[@orgid='{database}']"):
+            return
+
+        raise WrongParserError(
+            f'Database "{database}" was not found in Biocyc'
+        )
+
     @staticmethod
     def _read_file(filename: Path) -> Element:
         """
@@ -471,7 +502,6 @@ def retrieve_data(directory: Path, identifier: str, database: str) -> Element:
 
     if directory.exists():
         data_dir = directory.joinpath("PMN", database)
-        data_dir.mkdir(parents=True, exist_ok=True)
         filename = data_dir.joinpath(f"{identifier}.xml")
         debug_log.debug(f'Searching "{identifier}" in directory "{database}".')
         # Search for the file on directory. Otherwise retrive from database
@@ -491,7 +521,20 @@ def retrieve_data(directory: Path, identifier: str, database: str) -> Element:
                 response.raise_for_status()
                 # defining root
                 root = fromstring(response.text)
+
+                metadata = root.find("metadata/PGDB")
+                assert metadata is not None
+                orgid = metadata.get("orgid")
+                version = metadata.get("version")
+
+                BaseParser.check_database_version(
+                    directory,
+                    "pmn:" + str(orgid),
+                    str(version),
+                )
+
                 tree = ElementTree(root)
+                data_dir.mkdir(parents=True, exist_ok=True)
                 tree.write(str(filename))
                 debug_log.info(
                     f'Object "{identifier}" found in database. Saving in '
